@@ -10,8 +10,12 @@
 #endif
 #endif
 
+#ifndef R_NO_REMAP
 #define R_NO_REMAP
+#endif
+#ifndef STRICT_R_HEADERS
 #define STRICT_R_HEADERS
+#endif
 #include "Rinternals.h"
 
 // clang-format off
