@@ -9,17 +9,6 @@
 
 namespace quickjsr {
 
-// Used internally in QuickJS, but not exposed in the public API, so redefine it here
-static void js_free_prop_enum(JSContext *ctx, JSPropertyEnum *tab, uint32_t len) {
-  uint32_t i;
-  if (tab) {
-    for (i = 0; i < len; i++) {
-      JS_FreeAtom(ctx, tab[i].atom);
-    }
-    js_free(ctx, tab);
-  }
-}
-
 // Forward declaration to allow for recursive calls
 SEXP JSValue_to_SEXP(JSContext* ctx, const JSValue& val);
 
@@ -87,14 +76,12 @@ SEXP JSValue_to_SEXP_vector(JSContext* ctx, const JSValue& val) {
       }
     }
     case Object: {
-      uint32_t len;
-      JSValue arr_len = JS_GetPropertyStr(ctx, val, "length");
-      JS_ToUint32(ctx, &len, arr_len);
-      JS_FreeValue(ctx, arr_len);
+      int64_t len;
+      JS_GetLength(ctx, val, &len);
 
       cpp11::writable::list out(len);
-      for (uint32_t i = 0; i < len; i++) {
-        JSValue elem = JS_GetPropertyUint32(ctx, val, i);
+      for (int64_t i = 0; i < len; i++) {
+        JSValue elem = JS_GetPropertyInt64(ctx, val, i);
         out[static_cast<R_xlen_t>(i)] = JSValue_to_SEXP(ctx, elem);
         JS_FreeValue(ctx, elem);
       }
@@ -128,7 +115,7 @@ SEXP JSValue_to_SEXP_list(JSContext* ctx, const JSValue& val) {
     JS_FreeValue(ctx, elem);
     JS_FreeCString(ctx, key);
   }
-  js_free_prop_enum(ctx, tab, len);
+  JS_FreePropertyEnum(ctx, tab, len);
   out.attr("names") = keys;
   return out;
 }
